#
# spec file for package python-automaton
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-automaton
Version:        3.2.0
Release:        1.3
Summary:        Friendly state machines for python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/automaton
Source0:        https://files.pythonhosted.org/packages/source/a/automaton/automaton-3.2.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-PrettyTable >= 0.7.2
BuildRequires:  python3-devel
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-stestr
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Friendly state machines for python.

%package -n python3-automaton
Summary:        Friendly state machines for python
Requires:       python3-PrettyTable >= 0.7.2
Requires:       python3-pbr >= 2.0.0
Requires:       python3-six

%description -n python3-automaton
Friendly state machines for python.

This package contains the Python 3.x module.

%package -n python-automaton-doc
Summary:        Documentation for the Automaton Library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-automaton-doc
Documentation for the Automaton library.

%prep
%autosetup -p1 -n automaton-3.2.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the Sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-automaton
%doc README.rst
%license LICENSE
%{python3_sitelib}/automaton
%{python3_sitelib}/*.egg-info

%files -n python-automaton-doc
%license LICENSE
%doc doc/build/html

%changelog
* Fri Dec  1 2023 cloud-devel@suse.de
- update to version 3.2.0
  - Update master for stable/2023.1
* Tue Mar  7 2023 cloud-devel@suse.de
- update to version 3.1.0
  - Add Python3 antelope unit tests
  - Update master for stable/zed
* Sun Oct  2 2022 cloud-devel@suse.de
- update to version 3.0.1
  - Add Python3 zed unit tests
  - Remove unnecessary unicode prefixes
  - Update master for stable/yoga
  - Fix formatting of release list
  - Drop python3.6/3.7 support in testing runtime
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 2.5.0
  - Add Python3 yoga unit tests
  - doc: Avoid duplicate entry warning
  - Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.4.0
  - Moving to OFTC
  - tox: Remove references to testr
  - Add Python3 xena unit tests
  - setup.cfg: Replace dashes with underscores
  - Move flake8 as a pre-commit local target.
  - Update master for stable/wallaby
  - Remove lower-constraints remnants
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Remove six dependency
  - Dropping lower constraints testing
  - Uncap PrettyTable
  - Use TOX_CONSTRAINTS_FILE
  - Adding pre-commit
  - Use py3 as the default runtime for tox
  - Update master for stable/victoria
  - Add Python3 wallaby unit tests
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.0
  - Small cleanup
  - Stop to use the __future__ module.
  - Bump default tox env from py37 to py38
  - drop mock from lower-constraints
  - Update lower-constraints list
  - Update master for stable/ussuri
  - Add Python3 victoria unit tests
  - Add py38 package metadata
  - Switch to newer openstackdocstheme and reno versions
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.1
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - trivial: Remove noise
  - Ignore releasenote artifacts files.
  - Update hacking for Python3
  - Move doc requirements into dedicated file
  - Add python3 classifiers
  - Update master for stable/train
  - [ussuri][goal] Drop python 2.7 support and testing
  - Update the constraints url
  - Switch to Ussuri jobs
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.17.0
  - add python 3.7 unit test job
  - Add local bindep.txt
  - Update to opendev
  - Update master for stable/stein
  - Add Python 3 Train unit tests
  - OpenDev Migration Patch
  - Sync Sphinx requirement
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.16.0
  - add lib-forward-testing-python3 test job
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - Use template for lower-constraints
  - add python 3.6 unit test job
  - import zuul job settings from project-config
* Tue Sep 11 2018 cloud-devel@suse.de
- update to version 1.15.0
  - set default python to python3
  - fix tox python3 overrides
  - Update reno for stable/queens
  - Trivial: Update pypi url to new url
  - Switch to stestr
  - fix list of default virtualenvs
  - Updated from global requirements
  - add lower-constraints job
* Mon Sep  3 2018 dmueller@suse.com
- switch to stable/rocky spec template
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Thu Jan 18 2018 cloud-devel@suse.de
- update to version 1.14.0
  - Updated from global requirements
* Wed Dec 20 2017 cloud-devel@suse.de
- update to version 1.13.1
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
  - Remove kwarg default_start_state in the machine constructor
* Thu Sep 28 2017 cloud-devel@suse.de
- update to version 1.12.1
  - Update .gitreview for stable/pike
  - Updated from global requirements
  - Update UPPER_CONSTRAINTS_FILE for stable/pike
* Thu Aug 24 2017 tbechtold@suse.com
- Fix url
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.12.0
  - rearrange existing documentation according to the new standard layout
  - Update URLs in documents according to document migration
  - Remove support for py34
  - update link to docs in readme
  - Update reno for stable/ocata
  - Remove unused dependecy testscenarios
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.7.0:
  - Removes unnecessary utf-8 encoding
  - Add Constraints support
  - Updated from global requirements
  - Don't include openstack/common in flake8 exclude list
  - Changed the home-page link
  - Replace six.iteritems() with .items()
  - Fix release notes gate failure
  - Add reno for release notes management
* Fri Aug 26 2016 tbechtold@suse.com
- update to version 1.4.0:
  * Remove discover from test-requirements
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
- Update _service and switch to upstream spec template
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.2.0:
  * Add a state-space machine building example
  * Ensure state space can also pass on_enter/exit callbacks
  * Updated from global requirements
  * Updated from global requirements
  * Ensure machine special method(s) include in generated docs
  * Put py34 first in the envlist order of tox ,remove py33
  * Removes MANIFEST.in as it is not needed explicitely by PBR
  * Deprecated tox -downloadcache option removed
  * Updated from global requirements
  * Remove python 2.6 and cleanup tox.ini
  * Added code coverage section to tox
  * No need for Oslo Incubator Sync
  * Ignore generated files
  * docs - Set pbr 'warnerrors' option for doc build
  * Remove dummy/placeholder 'ChangeLog' as its not needed
  * Enhance the README
  * Fix the build path in .gitignore file
  * Updated from global requirements
  * Provide a finite machine build() method
  * Allow for raising on duplicate transition registration
- update Requires according to requirements.txt
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.7.0:
  * Updated from global requirements
  * Activate pep8 check that _ is imported
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
* Tue Jul 28 2015 tbechtold@suse.com
- update to 0.5.0:
  * Ensure doctesting and doc8 testing done in py27 env
  * Updated from global requirements
  * Remove setup.cfg 'requires-python' incorrect entry
  * Document `process_event` return and expose return namedtuple type
  * Allow providing and using a 'nested_start_state_fetcher'
- add _service
- update Requires according to requirements.txt
* Wed Jul 22 2015 dmueller@suse.com
- Initial package (0.4.0)
